@@ -475,6 +475,28 @@ pub mod macros {
             s.to_owned()
         };};
     }
+    /// remove_file_or_folder!() used to remove file or folder
+    /// ```rust
+    ///remove_file_or_folder!("./demo.txt");
+    ///remove_file_or_folder!("./target");
+    ///
+    /// ```
+    #[macro_export]
+    macro_rules! remove_file_or_folder {
+        ($path:expr) => {{
+            use std::fs;
+            use std::path::Path;
+            pub fn rm(path: &Path) {
+                if path.is_dir() {
+                    fs::remove_dir_all(path);
+                } else if path.is_file() {
+                    fs::remove_file(path);
+                }
+            }
+            let path = Path::new($path);
+            rm(path);
+        };};
+    }
 
     pub fn run() {}
 }
